@@ -6,6 +6,7 @@
  * Copyright 2005 David Snyder <dasnyderx@yahoo.com>
  * Copyright 2007 Joey Hess <joeyh@debian.org>
  * Copyright 2019 Joao Eriberto Mota Filho <eriberto@eriberto.pro.br>
+ * Copyright 2022 Sam James <sam@gentoo.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -50,6 +51,7 @@
 #include <stdio.h>
 #include <ctype.h>
 #include <err.h>
+#include <stdint.h>
 #include <string.h>
 #include <netdb.h>
 #include <unistd.h>
@@ -68,10 +70,10 @@ rfc868time_client (const char *hostname, int family, struct timeval *new,
 {
     struct addrinfo hints, *res0, *res;
     struct timeval old;
-    u_int32_t tim;	/* RFC 868 states clearly this is an uint32 */
+    uint32_t tim;	/* RFC 868 states clearly this is an uint32 */
     int s;
     int error;
-    u_int64_t td;
+    uint64_t td;
 
     memset(&hints, 0, sizeof(hints));
     hints.ai_family = family;
